SnowConfig class
Configuration of the Snow.
- Inheritance
-
- Object
- WeatherConfig
- SnowConfig
- Annotations
-
- @freezed
Constructors
- SnowConfig({@Default.new(20) int count, @Default.new(20.0) double size, @Default.new(Color.fromARGB(179, 255, 255, 255)) Color color, @ignoreJson @Default.new(Icons.ac_unit_rounded) IconData icon, @ignoreJson Widget? widgetSnowflake, @Default.new(90.0) double areaXStart, @Default.new(230.0) double areaXEnd, @Default.new(200.0) double areaYStart, @Default.new(540.0) double areaYEnd, @Default.new(20.0) double waveRangeMin, @Default.new(110.0) double waveRangeMax, @Default.new(5) int waveMinSec, @Default.new(20) int waveMaxSec, @Default.new(Curves.easeInOutSine) @ignoreJson Curve waveCurve, @Default.new(Curves.easeInCirc) @ignoreJson Curve fadeCurve, @Default.new(10) int fallMinSec, @Default.new(60) int fallMaxSec})
-
constfactory
-
SnowConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- areaXEnd → double
-
The X-axis zone where the snowflakes end to fall (in pixels).
no setterinherited
- areaXStart → double
-
The X-axis zone where the snowflakes start to fall (in pixels).
no setterinherited
- areaYEnd → double
-
The Y-axis zone where the snowflakes end to fall (in pixels).
no setterinherited
- areaYStart → double
-
The Y-axis zone where the snowflakes start to fall (in pixels).
no setterinherited
- color → Color
-
Snowflake color.
no setterinherited
-
copyWith
→ $SnowConfigCopyWith<
SnowConfig> -
Create a copy of SnowConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- count → int
-
Number of snowflakes.
no setterinherited
- fadeCurve → Curve
-
An parametric animation easing curve. Specify how fast the snowflakes will
disappear.
no setterinherited
- fallMaxSec → int
-
Maximum snowflake fall time (in seconds).
no setterinherited
- fallMinSec → int
-
Minimum snowflake fall time (in seconds).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
Snowflake icon. You can use a custom widget
widgetSnowflake.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
Snowflake size.
no setterinherited
- waveCurve → Curve
-
An parametric animation easing curve. Specify to create a wave effect.
no setterinherited
- waveMaxSec → int
-
Maximum wave effect duration time (in seconds).
no setterinherited
- waveMinSec → int
-
Minimum wave effect duration time (in seconds).
no setterinherited
- waveRangeMax → double
-
Maximum deviation from the direction of snowflake fall (in pixels).
no setterinherited
- waveRangeMin → double
-
Minimum deviation from the direction of snowflake fall (in pixels).
no setterinherited
- widgetSnowflake → Widget?
-
Specify the snowflake widget. In this case, the fields
sizeSnowflake,snowColorandiconDataSnowflakebe ignored.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this SnowConfig to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited